==> drustack-7.x-26.68.tar.gz: drustack/README.md <==
DruStack
========

[DruStack](http://drupal.org/project/drustack) is a freely available
packaged distribution of the open source Drupal system. A collection of
most common software from the Drupal community,
[DruStack](http://drupal.org/project/drustack) provides a quick on-ramp
to begin building Drupal websites.

[DruStack](http://drupal.org/project/drustack) integrated the
development for Drupal installation. The pre-configured modules make you
get a highly customized and total complete Drupal websites. You can get
your own ready-made Blog setup by default Drupal installation procedure.

DruStack replace most of the features and as a successor of [PantaRei
Siren](http://drupal.org/project/pantarei_siren) distribution.

### Features Highlight

-   Collection of 3rd party modules tested, verified and supported by
    [PantaRei Design](http://drupal.org/node/1741828).
-   Pre-configured with commonly used functionality, including testing
    user account, roles, permission, input filter, WYSIWYG, and even
    more.
-   Integrated with frequently-used 3rd party libraries, e.g.
    [CKEditor](http://ckeditor.com/), [HTML
    Purifier](http://htmlpurifier.org/),
    [Colorbox](http://colorpowered.com/colorbox/), [Code
    prettify](http://code.google.com/p/google-code-prettify/), etc.
-   Most setup managed by Features and Strongarm with drustack\_\*
    packages so you may rollback as default whenever required.

### Getting Start

#### Standard Package

Standard Package include both GPLv2+ compatibile
modules/themes/libraries as [Drupal.org Library Packaging
Whitelist](https://drupal.org/project/drupalorg_whitelist) required,
plus [TWBS](https://drupal.org/project/twbs) related packages for
[Bootstrap](http://getbootstrap.com/) mobile-first design integration.

If you are new with DruStack and hope to give a trial without any setup
overhead, please feel free to try DruStack on
[simplytest.me](http://simplytest.me/project/drustack/7.x-26.x), or
simply download it and install as like as normal Drupal core.

Build script for [drush](https://github.com/drush-ops/drush) make:

    curl -s -L http://bit.ly/LXoNm7 | ACTION=build PACKAGE=standard bash

Upgrade script for [drush](https://github.com/drush-ops/drush) make:

    curl -s -L http://bit.ly/LXoNm7 | ACTION=upgrade PACKAGE=standard bash

#### Full Package

Full Package include all modules/themes/libaries within our collections,
plus all patches for bugfix or usability improvement. Most packages are
tested in version compatibile, which site builder can kickstart a new
site without searching around popular projects.

Build script for [drush](https://github.com/drush-ops/drush) make:

    curl -s -L http://bit.ly/LXoNm7 | ACTION=build PACKAGE=full bash

Upgrade script for [drush](https://github.com/drush-ops/drush) make:

    curl -s -L http://bit.ly/LXoNm7 | ACTION=upgrade PACKAGE=full bash

#### Source Package

Source Package preserves VCS directories, link .git, for all Full
Package contents. A developer can get start with R&D and debug all in
GIT style without additional overhead, correct tag/branch will also
checkout for you automatically.

Build script for [drush](https://github.com/drush-ops/drush) make:

    curl -s -L http://bit.ly/LXoNm7 | ACTION=build PACKAGE=full SOURCE=true bash

Upgrade script for [drush](https://github.com/drush-ops/drush) make:

    curl -s -L http://bit.ly/LXoNm7 | ACTION=upgrade PACKAGE=full SOURCE=true bash

### Related modules

-   [DruStack Article](https://drupal.org/project/drustack_article)
-   [DruStack Blog](https://drupal.org/project/drustack_blog)
-   [DruStack Book Page](https://drupal.org/project/drustack_book)
-   [DruStack Commerce](https://drupal.org/project/drustack_commerce)
-   [DruStack Core](https://drupal.org/project/drustack_core)
-   [DruStack Devel](https://drupal.org/project/drustack_devel)
-   [DruStack Extra](https://drupal.org/project/drustack_extra)
-   [DruStack Forum Topic](https://drupal.org/project/drustack_forum)
-   [DruStack i18n](https://drupal.org/project/drustack_i18n)
-   [DruStack Basic Page](https://drupal.org/project/drustack_page)
-   [DruStack
    Performance](https://drupal.org/project/drustack_performance)
-   [DruStack Poll](https://drupal.org/project/drustack_poll)
-   [DruStack Search](https://drupal.org/project/drustack_search)
-   [DruStack SEO](https://drupal.org/project/drustack_seo)
-   [DruStack
    Simplenews](https://drupal.org/project/drustack_simplenews)
-   [DruStack Webform](https://drupal.org/project/drustack_webform)
-   [DruStack Workbench](https://drupal.org/project/drustack_workbench)
-   [DruStack WYSIWYG](https://drupal.org/project/drustack_wysiwyg)

### Author

-   Developed by [Edison Wong](http://drupal.org/user/33940).
-   Sponsored by [PantaRei Design](http://drupal.org/node/1741828).

==> drustack-7.x-30.77.tar.gz: drustack/README.md <==
DruStack
========

[DruStack](http://drupal.org/project/drustack) is a freely available
packaged distribution of the open source Drupal system. A collection of
most common software from the Drupal community,
[DruStack](http://drupal.org/project/drustack) provides a quick on-ramp
to begin building Drupal websites.

[DruStack](http://drupal.org/project/drustack) integrated the
development for Drupal installation. The pre-configured modules make you
get a highly customized and total complete Drupal websites. You can get
your own ready-made Blog setup by default Drupal installation procedure.

DruStack replace most of the features and as a successor of [PantaRei
Siren](http://drupal.org/project/pantarei_siren) distribution.

Features Highlight
------------------

-   Collection of 3rd party modules tested, verified and supported by
    [PantaRei Design](http://drupal.org/node/1741828).
-   Pre-configured with commonly used functionality, including testing
    user account, roles, permission, input filter, WYSIWYG, and even
    more.
-   Integrated with frequently-used 3rd party libraries, e.g.
    [CKEditor](http://ckeditor.com/), [HTML
    Purifier](http://htmlpurifier.org/),
    [Colorbox](http://colorpowered.com/colorbox/), [Code
    prettify](http://code.google.com/p/google-code-prettify/), etc.
-   Most setup managed by Features and Strongarm with drustack\_\*
    packages so you may rollback as default whenever required.

Getting Start
-------------

### Standard Package

Standard Package include both GPLv2+ compatibile
modules/themes/libraries as [Drupal.org Library Packaging
Whitelist](https://drupal.org/project/drupalorg_whitelist) required,
plus [TWBS](https://drupal.org/project/twbs) related packages for
[Bootstrap](http://getbootstrap.com/) mobile-first design integration.

If you are new with DruStack and hope to give a trial without any setup
overhead, please feel free to try DruStack on
[simplytest.me](http://simplytest.me/project/drustack/7.x-30.x), or
simply download it and install as like as normal Drupal core.

Build script for [drush](https://github.com/drush-ops/drush) make:

    curl -sL http://cgit.drupalcode.org/drustack/plain/drustack.sh | ACTION=build PACKAGE=standard bash

Upgrade script for [drush](https://github.com/drush-ops/drush) make:

    curl -sL http://cgit.drupalcode.org/drustack/plain/drustack.sh | ACTION=upgrade PACKAGE=standard bash

### Full Package

Full Package include all modules/themes/libaries within our collections,
plus all patches for bugfix or usability improvement. Most packages are
tested in version compatibile, which site builder can kickstart a new
site without searching around popular projects.

Build script for [drush](https://github.com/drush-ops/drush) make:

    curl -sL http://cgit.drupalcode.org/drustack/plain/drustack.sh | ACTION=build PACKAGE=full bash

Upgrade script for [drush](https://github.com/drush-ops/drush) make:

    curl -sL http://cgit.drupalcode.org/drustack/plain/drustack.sh | ACTION=upgrade PACKAGE=full bash

### Source Package

Source Package preserves VCS directories, link .git, for all Full
Package contents. A developer can get start with R&D and debug all in
GIT style without additional overhead, correct tag/branch will also
checkout for you automatically.

Build script for [drush](https://github.com/drush-ops/drush) make:

    curl -sL http://cgit.drupalcode.org/drustack/plain/drustack.sh | ACTION=build PACKAGE=full SOURCE=true bash

Upgrade script for [drush](https://github.com/drush-ops/drush) make:

    curl -sL http://cgit.drupalcode.org/drustack/plain/drustack.sh | ACTION=upgrade PACKAGE=full SOURCE=true bash

Related modules
---------------

-   [DruStack Article](https://drupal.org/project/drustack_article)
-   [DruStack Blog](https://drupal.org/project/drustack_blog)
-   [DruStack Book Page](https://drupal.org/project/drustack_book)
-   [DruStack Commerce](https://drupal.org/project/drustack_commerce)
-   [DruStack Core](https://drupal.org/project/drustack_core)
-   [DruStack Devel](https://drupal.org/project/drustack_devel)
-   [DruStack Extra](https://drupal.org/project/drustack_extra)
-   [DruStack Forum Topic](https://drupal.org/project/drustack_forum)
-   [DruStack i18n](https://drupal.org/project/drustack_i18n)
-   [DruStack Basic Page](https://drupal.org/project/drustack_page)
-   [DruStack
    Performance](https://drupal.org/project/drustack_performance)
-   [DruStack Poll](https://drupal.org/project/drustack_poll)
-   [DruStack Search](https://drupal.org/project/drustack_search)
-   [DruStack SEO](https://drupal.org/project/drustack_seo)
-   [DruStack
    Simplenews](https://drupal.org/project/drustack_simplenews)
-   [DruStack Webform](https://drupal.org/project/drustack_webform)
-   [DruStack Workbench](https://drupal.org/project/drustack_workbench)
-   [DruStack WYSIWYG](https://drupal.org/project/drustack_wysiwyg)

Author
------

-   Developed by [Edison Wong](http://drupal.org/user/33940).
-   Sponsored by [PantaRei Design](http://drupal.org/node/1741828).
